@@ -5,7 +5,7 @@
 import subprocess
 
 from .github_release import download_latest_release
-from .models import Conf
+from .util import Conf
 from .util import get_user_repo_from_url
 from .util import read_json
 
